# Sensor validation

Sensor data quality plays a vital role in Internet of Things (IoT) applications as they are rendered useless if the data quality is bad.


::: ceruleo.dataset.analysis.numerical_features
    handler: python
    options:
      members:
        - analysis
        - analysis_single_time_series


## Analysis elements

::: ceruleo.dataset.analysis.numerical_features
    handler: python
    options:
      members:
        - entropy
        - n_unique
        - null
        - monotonicity
        - autocorrelation
        - correlation
        - mutual_information